/*===========================================================================*/
/*   (Prof/unit.scm)                                                         */
/*   Bigloo (4.6a)                                                           */
/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
/*===========================================================================*/
/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Prof/unit.scm) */
/* GC selection */
#define THE_GC BOEHM_GC

/* unsafe mode */
#define BIGLOO_UNSAFE 1

/* traces mode */
#define BIGLOO_TRACE 0

/* standard Bigloo include */
#include <bigloo.h>

#ifdef __cplusplus
extern "C"
{
#endif
#ifndef BGL_MODULE_TYPE_DEFINITIONS
#define BGL_MODULE_TYPE_DEFINITIONS
#ifndef BGL_PROF_WALK_TYPE_DEFINITIONS
#define BGL_PROF_WALK_TYPE_DEFINITIONS

/* object type definitions */
	typedef struct BgL_backendz00_bgl
	{
		header_t header;
		obj_t widening;
		obj_t BgL_languagez00;
		obj_t BgL_srfi0z00;
		obj_t BgL_namez00;
		obj_t BgL_externzd2variableszd2;
		obj_t BgL_externzd2functionszd2;
		obj_t BgL_externzd2typeszd2;
		obj_t BgL_variablesz00;
		obj_t BgL_functionsz00;
		obj_t BgL_typesz00;
		bool_t BgL_typedz00;
		obj_t BgL_heapzd2suffixzd2;
		obj_t BgL_heapzd2compatiblezd2;
		bool_t BgL_callccz00;
		bool_t BgL_qualifiedzd2typeszd2;
		bool_t BgL_effectzb2zb2;
		bool_t BgL_removezd2emptyzd2letz00;
		bool_t BgL_foreignzd2closurezd2;
		bool_t BgL_typedzd2eqzd2;
		bool_t BgL_tracezd2supportzd2;
		obj_t BgL_foreignzd2clausezd2supportz00;
		obj_t BgL_debugzd2supportzd2;
		bool_t BgL_pragmazd2supportzd2;
		bool_t BgL_tvectorzd2descrzd2supportz00;
		bool_t BgL_requirezd2tailczd2;
		obj_t BgL_registersz00;
		obj_t BgL_pregistersz00;
		bool_t BgL_boundzd2checkzd2;
		bool_t BgL_typezd2checkzd2;
		bool_t BgL_typedzd2funcallzd2;
		bool_t BgL_strictzd2typezd2castz00;
		bool_t BgL_forcezd2registerzd2gczd2rootszd2;
		bool_t BgL_stringzd2literalzd2supportz00;
		bool_t BgL_boxedzd2fixnumszd2;
		bool_t BgL_typedzd2closureszd2;
	}                 *BgL_backendz00_bglt;


#endif													// BGL_PROF_WALK_TYPE_DEFINITIONS
#endif													// BGL_MODULE_TYPE_DEFINITIONS

	static obj_t BGl_requirezd2initializa7ationz75zzprof_walkz00 = BUNSPEC;
	static obj_t BGl_toplevelzd2initzd2zzprof_walkz00(void);
	extern obj_t BGl_internalzd2errorzd2zztools_errorz00(obj_t, obj_t, obj_t);
	extern obj_t BGl_getzd2toplevelzd2unitzd2weightzd2zzmodule_includez00(void);
	static obj_t BGl_genericzd2initzd2zzprof_walkz00(void);
	static obj_t BGl_objectzd2initzd2zzprof_walkz00(void);
	BGL_IMPORT obj_t BGl_2zb2zb2zz__r4_numbers_6_5z00(obj_t, obj_t);
	BGL_IMPORT obj_t bgl_bignum_add(obj_t, obj_t);
	extern obj_t BGl_thezd2backendzd2zzbackend_backendz00(void);
	BGL_IMPORT obj_t BGl_readz00zz__readerz00(obj_t, obj_t);
	BGL_IMPORT obj_t BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00(obj_t,
		obj_t, obj_t);
	static obj_t BGl_methodzd2initzd2zzprof_walkz00(void);
	extern obj_t BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00;
	BGL_IMPORT obj_t bgl_long_to_bignum(long);
	BGL_EXPORTED_DECL obj_t BGl_modulezd2initializa7ationz75zzprof_walkz00(long,
		char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzbackend_backendz00(long,
		char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_nodez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzast_varz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzmodule_includez00(long,
		char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztype_typez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzengine_paramz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztools_shapez00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zzengine_passz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztools_errorz00(long, char *);
	extern obj_t BGl_modulezd2initializa7ationz75zztools_speekz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__r4_ports_6_10_1z00(long,
		char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__r4_strings_6_7z00(long,
		char *);
	BGL_IMPORT obj_t
		BGl_modulezd2initializa7ationz75zz__r4_numbers_6_5_fixnumz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__r4_numbers_6_5z00(long,
		char *);
	BGL_IMPORT obj_t
		BGl_modulezd2initializa7ationz75zz__r4_pairs_and_lists_6_3z00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__readerz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__bignumz00(long, char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__structurez00(long,
		char *);
	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__biglooz00(long, char *);
	BGL_IMPORT obj_t create_struct(obj_t, int);
	static obj_t BGl_cnstzd2initzd2zzprof_walkz00(void);
	static obj_t BGl_libraryzd2moduleszd2initz00zzprof_walkz00(void);
	static obj_t BGl_importedzd2moduleszd2initz00zzprof_walkz00(void);
	static obj_t BGl_gczd2rootszd2initz00zzprof_walkz00(void);
	static obj_t BGl_z62makezd2profzd2unitz62zzprof_walkz00(obj_t);
	extern obj_t BGl_za2currentzd2passza2zd2zzengine_passz00;
	BGL_EXPORTED_DECL obj_t BGl_makezd2profzd2unitz00zzprof_walkz00(void);
	extern obj_t BGl_verbosez00zztools_speekz00(obj_t, obj_t);
	static obj_t __cnst[6];


	   
		 
		DEFINE_STRING(BGl_string1367z00zzprof_walkz00,
		BgL_bgl_string1367za700za7za7p1377za7, "Prof", 4);
	      DEFINE_STRING(BGl_string1368z00zzprof_walkz00,
		BgL_bgl_string1368za700za7za7p1378za7, "   . ", 5);
	      DEFINE_STRING(BGl_string1369z00zzprof_walkz00,
		BgL_bgl_string1369za700za7za7p1379za7, "failure during prelude hook", 27);
	      DEFINE_STRING(BGl_string1370z00zzprof_walkz00,
		BgL_bgl_string1370za700za7za7p1380za7, "prof_walk", 9);
	      DEFINE_STRING(BGl_string1371z00zzprof_walkz00,
		BgL_bgl_string1371za700za7za7p1381za7,
		"unit prof begin (begin (pragma \"write_bprof_table()\")) #z100 pass-started ",
		74);
	     
		DEFINE_EXPORT_BGL_PROCEDURE(BGl_makezd2profzd2unitzd2envzd2zzprof_walkz00,
		BgL_bgl_za762makeza7d2profza7d1382za7,
		BGl_z62makezd2profzd2unitz62zzprof_walkz00, 0L, BUNSPEC, 0);

/* GC roots registration */
	static obj_t bgl_gc_roots_register()
	{
#if defined( BGL_GC_ROOTS )
#define ADD_ROOT( addr ) (addr > roots_max ? roots_max = addr : (addr < roots_min ? roots_min = addr : 0))
		void *roots_min = (void *) ULONG_MAX, *roots_max = 0;
		     ADD_ROOT((void *) (&BGl_requirezd2initializa7ationz75zzprof_walkz00));
#undef ADD_ROOT
		if   (roots_max > 0)
			     GC_add_roots(roots_min, ((void **) roots_max) + 1);
#endif
		     return BUNSPEC;
	}



/* module-initialization */
	BGL_EXPORTED_DEF obj_t BGl_modulezd2initializa7ationz75zzprof_walkz00(long
		BgL_checksumz00_1725, char *BgL_fromz00_1726)
	{
		{
			if (CBOOL(BGl_requirezd2initializa7ationz75zzprof_walkz00))
				{
					BGl_requirezd2initializa7ationz75zzprof_walkz00 = BBOOL(((bool_t) 0));
					BGl_gczd2rootszd2initz00zzprof_walkz00();
					BGl_libraryzd2moduleszd2initz00zzprof_walkz00();
					BGl_cnstzd2initzd2zzprof_walkz00();
					BGl_importedzd2moduleszd2initz00zzprof_walkz00();
					return BGl_toplevelzd2initzd2zzprof_walkz00();
				}
			else
				{
					return BUNSPEC;
				}
		}

	}



/* library-modules-init */
	obj_t BGl_libraryzd2moduleszd2initz00zzprof_walkz00(void)
	{
		{	/* Prof/unit.scm 15 */
			BGl_modulezd2initializa7ationz75zz__r4_numbers_6_5z00(0L, "prof_walk");
			BGl_modulezd2initializa7ationz75zz__readerz00(0L, "prof_walk");
			BGl_modulezd2initializa7ationz75zz__r4_ports_6_10_1z00(0L, "prof_walk");
			BGl_modulezd2initializa7ationz75zz__r4_strings_6_7z00(0L, "prof_walk");
			BGl_modulezd2initializa7ationz75zz__bignumz00(0L, "prof_walk");
			BGl_modulezd2initializa7ationz75zz__r4_numbers_6_5_fixnumz00(0L,
				"prof_walk");
			BGl_modulezd2initializa7ationz75zz__r4_pairs_and_lists_6_3z00(0L,
				"prof_walk");
			BGl_modulezd2initializa7ationz75zz__structurez00(0L, "prof_walk");
			BGl_modulezd2initializa7ationz75zz__biglooz00(0L, "prof_walk");
			return BUNSPEC;
		}

	}



/* cnst-init */
	obj_t BGl_cnstzd2initzd2zzprof_walkz00(void)
	{
		{	/* Prof/unit.scm 15 */
			{	/* Prof/unit.scm 15 */
				obj_t BgL_cportz00_1714;

				{	/* Prof/unit.scm 15 */
					obj_t BgL_stringz00_1721;

					BgL_stringz00_1721 = BGl_string1371z00zzprof_walkz00;
					{	/* Prof/unit.scm 15 */
						obj_t BgL_startz00_1722;

						BgL_startz00_1722 = BINT(0L);
						{	/* Prof/unit.scm 15 */
							obj_t BgL_endz00_1723;

							BgL_endz00_1723 =
								BINT(STRING_LENGTH(((obj_t) BgL_stringz00_1721)));
							{	/* Prof/unit.scm 15 */

								BgL_cportz00_1714 =
									BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00
									(BgL_stringz00_1721, BgL_startz00_1722, BgL_endz00_1723);
				}}}}
				{
					long BgL_iz00_1715;

					BgL_iz00_1715 = 5L;
				BgL_loopz00_1716:
					if ((BgL_iz00_1715 == (-1L)))
						{	/* Prof/unit.scm 15 */
							return BUNSPEC;
						}
					else
						{	/* Prof/unit.scm 15 */
							{	/* Prof/unit.scm 15 */
								obj_t BgL_arg1376z00_1717;

								{	/* Prof/unit.scm 15 */

									{	/* Prof/unit.scm 15 */
										obj_t BgL_locationz00_1719;

										BgL_locationz00_1719 = BBOOL(((bool_t) 0));
										{	/* Prof/unit.scm 15 */

											BgL_arg1376z00_1717 =
												BGl_readz00zz__readerz00(BgL_cportz00_1714,
												BgL_locationz00_1719);
										}
									}
								}
								{	/* Prof/unit.scm 15 */
									int BgL_tmpz00_1753;

									BgL_tmpz00_1753 = (int) (BgL_iz00_1715);
									CNST_TABLE_SET(BgL_tmpz00_1753, BgL_arg1376z00_1717);
							}}
							{	/* Prof/unit.scm 15 */
								int BgL_auxz00_1720;

								BgL_auxz00_1720 = (int) ((BgL_iz00_1715 - 1L));
								{
									long BgL_iz00_1758;

									BgL_iz00_1758 = (long) (BgL_auxz00_1720);
									BgL_iz00_1715 = BgL_iz00_1758;
									goto BgL_loopz00_1716;
								}
							}
						}
				}
			}
		}

	}



/* gc-roots-init */
	obj_t BGl_gczd2rootszd2initz00zzprof_walkz00(void)
	{
		{	/* Prof/unit.scm 15 */
			return bgl_gc_roots_register();
		}

	}



/* toplevel-init */
	obj_t BGl_toplevelzd2initzd2zzprof_walkz00(void)
	{
		{	/* Prof/unit.scm 15 */
			return BUNSPEC;
		}

	}



/* make-prof-unit */
	BGL_EXPORTED_DEF obj_t BGl_makezd2profzd2unitz00zzprof_walkz00(void)
	{
		{	/* Prof/unit.scm 31 */
			{	/* Prof/unit.scm 32 */
				obj_t BgL_list1253z00_1493;

				{	/* Prof/unit.scm 32 */
					obj_t BgL_arg1254z00_1494;

					{	/* Prof/unit.scm 32 */
						obj_t BgL_arg1255z00_1495;

						BgL_arg1255z00_1495 =
							MAKE_YOUNG_PAIR(BCHAR(((unsigned char) 10)), BNIL);
						BgL_arg1254z00_1494 =
							MAKE_YOUNG_PAIR(BGl_string1367z00zzprof_walkz00,
							BgL_arg1255z00_1495);
					}
					BgL_list1253z00_1493 =
						MAKE_YOUNG_PAIR(BGl_string1368z00zzprof_walkz00,
						BgL_arg1254z00_1494);
				}
				BGl_verbosez00zztools_speekz00(BINT(1L), BgL_list1253z00_1493);
			}
			BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00 = BINT(0L);
			BGl_za2currentzd2passza2zd2zzengine_passz00 =
				BGl_string1367z00zzprof_walkz00;
			{	/* Prof/unit.scm 32 */
				obj_t BgL_g1107z00_1496;

				BgL_g1107z00_1496 = BNIL;
				{
					obj_t BgL_hooksz00_1499;
					obj_t BgL_hnamesz00_1500;

					BgL_hooksz00_1499 = BgL_g1107z00_1496;
					BgL_hnamesz00_1500 = BNIL;
				BgL_zc3z04anonymousza31256ze3z87_1501:
					if (NULLP(BgL_hooksz00_1499))
						{	/* Prof/unit.scm 32 */
							((obj_t) CNST_TABLE_REF(0));
						}
					else
						{	/* Prof/unit.scm 32 */
							bool_t BgL_test1391z00_1772;

							{	/* Prof/unit.scm 32 */
								obj_t BgL_fun1270z00_1508;

								BgL_fun1270z00_1508 = CAR(((obj_t) BgL_hooksz00_1499));
								BgL_test1391z00_1772 =
									CBOOL(BGL_PROCEDURE_CALL0(BgL_fun1270z00_1508));
							}
							if (BgL_test1391z00_1772)
								{	/* Prof/unit.scm 32 */
									obj_t BgL_arg1260z00_1505;
									obj_t BgL_arg1262z00_1506;

									BgL_arg1260z00_1505 = CDR(((obj_t) BgL_hooksz00_1499));
									BgL_arg1262z00_1506 = CDR(((obj_t) BgL_hnamesz00_1500));
									{
										obj_t BgL_hnamesz00_1784;
										obj_t BgL_hooksz00_1783;

										BgL_hooksz00_1783 = BgL_arg1260z00_1505;
										BgL_hnamesz00_1784 = BgL_arg1262z00_1506;
										BgL_hnamesz00_1500 = BgL_hnamesz00_1784;
										BgL_hooksz00_1499 = BgL_hooksz00_1783;
										goto BgL_zc3z04anonymousza31256ze3z87_1501;
									}
								}
							else
								{	/* Prof/unit.scm 32 */
									obj_t BgL_arg1266z00_1507;

									BgL_arg1266z00_1507 = CAR(((obj_t) BgL_hnamesz00_1500));
									BGl_internalzd2errorzd2zztools_errorz00
										(BGl_string1367z00zzprof_walkz00,
										BGl_string1369z00zzprof_walkz00, BgL_arg1266z00_1507);
								}
						}
				}
			}
			{	/* Prof/unit.scm 34 */
				obj_t BgL_arg1272z00_1511;
				obj_t BgL_arg1273z00_1512;

				{	/* Prof/unit.scm 34 */
					obj_t BgL_b1226z00_1513;

					BgL_b1226z00_1513 =
						BGl_getzd2toplevelzd2unitzd2weightzd2zzmodule_includez00();
					if (INTEGERP(BgL_b1226z00_1513))
						{	/* Prof/unit.scm 34 */
							obj_t BgL_tmpz00_1696;

							BgL_tmpz00_1696 = BINT(0L);
							{	/* Prof/unit.scm 34 */
								bool_t BgL_test1393z00_1792;

								{	/* Prof/unit.scm 34 */
									obj_t BgL_tmpz00_1793;

									BgL_tmpz00_1793 = BINT(100L);
									BgL_test1393z00_1792 =
										BGL_ADDFX_OV(BgL_tmpz00_1793, BgL_b1226z00_1513,
										BgL_tmpz00_1696);
								}
								if (BgL_test1393z00_1792)
									{	/* Prof/unit.scm 34 */
										BgL_arg1272z00_1511 =
											bgl_bignum_add(
											((obj_t)
												CNST_TABLE_REF(1)),
											bgl_long_to_bignum((long) CINT(BgL_b1226z00_1513)));
									}
								else
									{	/* Prof/unit.scm 34 */
										BgL_arg1272z00_1511 = BgL_tmpz00_1696;
									}
							}
						}
					else
						{	/* Prof/unit.scm 34 */
							BgL_arg1272z00_1511 =
								BGl_2zb2zb2zz__r4_numbers_6_5z00(BINT(100L), BgL_b1226z00_1513);
						}
				}
				{	/* Prof/unit.scm 35 */
					bool_t BgL_test1394z00_1803;

					{	/* Prof/unit.scm 35 */
						obj_t BgL_arg1277z00_1517;

						BgL_arg1277z00_1517 = BGl_thezd2backendzd2zzbackend_backendz00();
						BgL_test1394z00_1803 =
							(((BgL_backendz00_bglt) COBJECT(
									((BgL_backendz00_bglt) BgL_arg1277z00_1517)))->
							BgL_pragmazd2supportzd2);
					}
					if (BgL_test1394z00_1803)
						{	/* Prof/unit.scm 35 */
							BgL_arg1273z00_1512 = ((obj_t) CNST_TABLE_REF(2));
						}
					else
						{	/* Prof/unit.scm 37 */
							obj_t BgL_arg1276z00_1516;

							BgL_arg1276z00_1516 = MAKE_YOUNG_PAIR(BUNSPEC, BNIL);
							BgL_arg1273z00_1512 =
								MAKE_YOUNG_PAIR(
								((obj_t) CNST_TABLE_REF(3)), BgL_arg1276z00_1516);
						}
				}
				{	/* Prof/unit.scm 33 */
					obj_t BgL_idz00_1705;

					BgL_idz00_1705 = ((obj_t) CNST_TABLE_REF(4));
					{	/* Prof/unit.scm 33 */
						obj_t BgL_newz00_1706;

						BgL_newz00_1706 =
							create_struct(((obj_t) CNST_TABLE_REF(5)), (int) (5L));
						{	/* Prof/unit.scm 33 */
							int BgL_tmpz00_1819;

							BgL_tmpz00_1819 = (int) (4L);
							STRUCT_SET(BgL_newz00_1706, BgL_tmpz00_1819, BFALSE);
						}
						{	/* Prof/unit.scm 33 */
							int BgL_tmpz00_1822;

							BgL_tmpz00_1822 = (int) (3L);
							STRUCT_SET(BgL_newz00_1706, BgL_tmpz00_1822, BTRUE);
						}
						{	/* Prof/unit.scm 33 */
							int BgL_tmpz00_1825;

							BgL_tmpz00_1825 = (int) (2L);
							STRUCT_SET(BgL_newz00_1706, BgL_tmpz00_1825, BgL_arg1273z00_1512);
						}
						{	/* Prof/unit.scm 33 */
							int BgL_tmpz00_1828;

							BgL_tmpz00_1828 = (int) (1L);
							STRUCT_SET(BgL_newz00_1706, BgL_tmpz00_1828, BgL_arg1272z00_1511);
						}
						{	/* Prof/unit.scm 33 */
							int BgL_tmpz00_1831;

							BgL_tmpz00_1831 = (int) (0L);
							STRUCT_SET(BgL_newz00_1706, BgL_tmpz00_1831, BgL_idz00_1705);
						}
						return BgL_newz00_1706;
					}
				}
			}
		}

	}



/* &make-prof-unit */
	obj_t BGl_z62makezd2profzd2unitz62zzprof_walkz00(obj_t BgL_envz00_1712)
	{
		{	/* Prof/unit.scm 31 */
			return BGl_makezd2profzd2unitz00zzprof_walkz00();
		}

	}



/* object-init */
	obj_t BGl_objectzd2initzd2zzprof_walkz00(void)
	{
		{	/* Prof/unit.scm 15 */
			return BUNSPEC;
		}

	}



/* generic-init */
	obj_t BGl_genericzd2initzd2zzprof_walkz00(void)
	{
		{	/* Prof/unit.scm 15 */
			return BUNSPEC;
		}

	}



/* method-init */
	obj_t BGl_methodzd2initzd2zzprof_walkz00(void)
	{
		{	/* Prof/unit.scm 15 */
			return BUNSPEC;
		}

	}



/* imported-modules-init */
	obj_t BGl_importedzd2moduleszd2initz00zzprof_walkz00(void)
	{
		{	/* Prof/unit.scm 15 */
			BGl_modulezd2initializa7ationz75zztools_speekz00(61247943L,
				BSTRING_TO_STRING(BGl_string1370z00zzprof_walkz00));
			BGl_modulezd2initializa7ationz75zztools_errorz00(300504031L,
				BSTRING_TO_STRING(BGl_string1370z00zzprof_walkz00));
			BGl_modulezd2initializa7ationz75zzengine_passz00(373082237L,
				BSTRING_TO_STRING(BGl_string1370z00zzprof_walkz00));
			BGl_modulezd2initializa7ationz75zztools_shapez00(365925558L,
				BSTRING_TO_STRING(BGl_string1370z00zzprof_walkz00));
			BGl_modulezd2initializa7ationz75zzengine_paramz00(161876678L,
				BSTRING_TO_STRING(BGl_string1370z00zzprof_walkz00));
			BGl_modulezd2initializa7ationz75zztype_typez00(515343395L,
				BSTRING_TO_STRING(BGl_string1370z00zzprof_walkz00));
			BGl_modulezd2initializa7ationz75zzmodule_includez00(184800657L,
				BSTRING_TO_STRING(BGl_string1370z00zzprof_walkz00));
			BGl_modulezd2initializa7ationz75zzast_varz00(90839984L,
				BSTRING_TO_STRING(BGl_string1370z00zzprof_walkz00));
			BGl_modulezd2initializa7ationz75zzast_nodez00(469732712L,
				BSTRING_TO_STRING(BGl_string1370z00zzprof_walkz00));
			return
				BGl_modulezd2initializa7ationz75zzbackend_backendz00(216206620L,
				BSTRING_TO_STRING(BGl_string1370z00zzprof_walkz00));
		}

	}

#ifdef __cplusplus
}
#endif
